<?php
/**
 * classes/ibit_Action_EvaluationAdministration.class.php
 *
 * @author  Michael Riehemann <michael.riehemann@uni-oldenburg.de>
 * @author  Jan-Hendrik Willms <tleilax@mindfuck.de>
 * @author  Ivn Marcos <ivan.marcos@gmx.net>
 * @author  Nico Mueller <nico.mueller@uni-oldenburg.de>
 * @package IBIT_Evaluation
 * @copyright Copyright 2006, 2007 IBIT
 * @version 2.0.9
 */

/**
 * Die Klasse zur Evaluationsverwaltung
 *
 * Diese Klasse bernimmt die Verwaltung der Evaluationen. Es werden Funktionen zum Anzeigen, Bearbeiten und Lschen von Evaluationen
 * bereitgestellt.
 *
 * @author     Jan-Hendrik Willms <tleilax@mindfuck.de>
 * @author     Michael Riehemann <michael.riehemann@uni-oldenburg.de>
 * @package    IBIT_Evaluation
 * @subpackage Action
 * @copyright  Copyright 2006, 2007 IBIT
 * @version    2.0.9
 */
class ibit_Action_EvaluationAdministration
{
	/**
	 * Referenz auf das aufrufende Objekt
	 * @var object $parent
	 */
	var $parent;

	/**
	 * Der Konstruktor der Klasse.
	 * @param object $parent Referenz auf das aufrufende Objekt
	 */
	function ibit_Action_EvaluationAdministration($parent)
	{
		$this->parent = $parent;

		$this->save_display_params();
	}

	/**
	 * Zeigt den Header der Seite an.
	 * @param string $command Aktuelles Kommando
	 * @uses ibit_Helper::getSemester()
	 */
	function displayHeader($command)
	{
		$institute_view = false;
		$params = '';
		if ( !empty( $_REQUEST['faculty_id'] ) )
		{
			$params .= '&faculty_id='.$_REQUEST['faculty_id'];
		}
		if ( !empty( $_REQUEST['institute_id'] ) )
		{
			$params .= '&institute_id='.$_REQUEST['institute_id'];
			$institute_view = true;
		}
		if (!empty( $_REQUEST['skip'] ) )
		{
			$params .= '&skip='.$_REQUEST['skip'];
		}

		if (empty($command))
		{
			$command = 'show_faculties';
		}

		$template = $this->parent->parent->getTemplate('admin_evaluation_administration_header.php');
		$template->set_attribute('link_evaluation_customize', $this->parent->base_link.'&command='.$command.$params);
		$template->set_attribute('semester_data', ibit_Helper::getSemester());
		$template->set_attribute('institute_view', $institute_view);
		echo $template->render();
	}

	/**
	 * Speichert die im Request bergebenen Darstellungsparameter.
	 * @uses ibit_Helper::getSemester()
	 */
	function save_display_params()
	{
		if (!isset($_SESSION['show_expired']))
		{
			$_SESSION['show_expired'] = 1;
			$_SESSION['show_current'] = 1;
			$_SESSION['show_future'] = 1;
			$_SESSION['evaladmin_maxrows'] = 25;
			$_SESSION['semester_id'] = -1;
			$semester_data = ibit_Helper::getSemester();
			foreach ($semester_data as $semester)
			{
				if ($semester['currentsemester'])
				{
					$_SESSION['semester_id'] = $semester['id'];
				}
			}
		}

		if (!empty($_GET['show_expired']))
		{
			$_SESSION['show_expired'] = $_GET['show_expired'];
		}
		if (!empty($_GET['show_current']))
		{
			$_SESSION['show_current'] = $_GET['show_current'];
		}
		if (!empty($_GET['show_future']))
		{
			$_SESSION['show_future'] = $_GET['show_future'];
		}

		if (empty($_POST['semester_id']))
		{
			return;
		}

		$_SESSION['semester_id'] = $_POST['semester_id'];
		$_SESSION['show_expired'] = !empty($_POST['show_expired']);
		$_SESSION['show_current'] = !empty($_POST['show_current']);
		$_SESSION['show_future'] = !empty($_POST['show_future']);
		$_SESSION['show_notempty'] = !empty($_POST['show_notempty']);
		$_SESSION['show_notguilty'] = !empty($_POST['show_notguilty']);
		$_SESSION['evaladmin_maxrows'] = empty($_POST['evaladmin_maxrows']) ? 40 : $_POST['evaladmin_maxrows'];
	}

	/**
	 * Lscht alle Evaluationen der bergebenen Institute in Abhngigkeit der Sichtbarkeitseinstellungen (abgelaufen, laufend, zuknftig).
	 * @param mixed $institute_id Id des Instituts
	 * @return int Anzahl der gelschten Evaluationen
	 * @uses ibit_Evaluation::getExpiredEvaluationsByInstituteId()
	 * @uses ibit_Evaluation::getCurrentEvaluationsByInstituteId()
	 * @uses ibit_Evaluation::getFutureEvaluationsByInstituteId()
	 * @uses ibit_Evaluation::delete()
	 */
	function deleteEvaluationsByInstituteId( $institute_ids )
	{
		$eval_count = 0;
		$evaluation_data = array();

		if ($_SESSION['show_expired'])
		{
			$evaluation_data = array_merge($evaluation_data, ibit_Evaluation::getExpiredEvaluationsByInstituteId($institute_ids, $foo=null, $bar=null, $count, $_SESSION['semester_id'], true));
			$eval_count += $count;
		}

		if ($_SESSION['show_current'])
		{
			$evaluation_data = array_merge($evaluation_data, ibit_Evaluation::getCurrentEvaluationsByInstituteId($institute_ids, $foo=null, $bar=null, $count, $_SESSION['semester_id'], true));
			$eval_count += $count;
		}

		if ($_SESSION['show_future'])
		{
			$evaluation_data = array_merge($evaluation_data, ibit_Evaluation::getFutureEvaluationsByInstituteId($institute_ids, $foo=null, $bar=null, $count, $_SESSION['semester_id'], true));
			$eval_count += $count;
		}

		$ids = array();
		foreach ($evaluation_data as $evaluation)
		{
			array_push($ids, $evaluation['evaluation_id']);
		}
		ibit_Evaluation::delete($ids);
		return $eval_count;
	}

	/**
	 * Zeigt die Details und das Formular zum Bearbeiten einer Evaluation an.
	 * @param int $evaluation_id Id der Evaluation
	 * @uses ibit_Evaluation
	 * @uses ibit_Action_Summary
	 */
	function evaluation_details($evaluation_id, $fakview=false)
	{
		$evaluation = new ibit_Evaluation($evaluation_id);

		$template = $this->parent->parent->getTemplate('admin_evaluation_administration_edit_evaluation');
		$template->set_attribute('link_confirm', $this->parent->base_link.'&command=edit_evaluation&evaluation_id='.$evaluation_id.'&skip='.$_REQUEST['skip'].'&institute_id='.$evaluation->getInstitutId());
		$template->set_attribute('link_cancel', $this->parent->base_link.'&command=show_institute&institute_id='.$evaluation->getInstitutId().'&skip='.$_REQUEST['skip']);
		$template->set_attribute('evaluation', $evaluation->flattenToArray());

		if (!$fakview)
		{
			echo $template->render();
		}

		if ($evaluation->getStopDate() < time() and $evaluation->getNumberOfParticipants() >= ibit_EvaluationConfig::GetConfig('evaluation', 'min_users'))
		{
			$summary = new ibit_Action_Summary($this->parent->parent, $evaluation_id);
			$summary->show();
		}
		elseif($evaluation->getStopDate() < time() and $evaluation->getNumberOfParticipants() < ibit_EvaluationConfig::GetConfig('evaluation', 'min_users'))
		{
			$this->parent->parent->reportError('Die Auswertung kann nicht angezeigt werden, da zu wenig Teinehmer vorhanden sind.');
		}
		elseif($evaluation->getStopDate() > time())
		{
			$this->parent->parent->reportError('Die Auswertung kann nicht angezeigt werden, da diese noch nicht beendet ist.');
		}

	}


	/**
	 * Speichert die nderungen an einer Evaluation.
	 * @param int $evaluation_id Id der Evaluation
	 * @uses ibit_Evaluation
	 */
	function edit_evaluation( $evaluation_id )
	{
		$evaluation = new ibit_Evaluation( $evaluation_id );

		$error = array();
		ibit_Helper::checkNumber($_POST['start_day'], 1, 31, 'Start-Tag', $error);
		ibit_Helper::checkNumber($_POST['start_month'], 1, 12, 'Start-Monat', $error);
		ibit_Helper::checkNumber($_POST['start_year'], 2000, null, 'Start-Jahr', $error);
		ibit_Helper::checkNumber($_POST['stop_day'], 1, 31, 'End-Tag', $error);
		ibit_Helper::checkNumber($_POST['stop_month'], 1, 12, 'End-Monat', $error);
		ibit_Helper::checkNumber($_POST['stop_year'], 2000, null, 'End-Jahr', $error);

		if (empty($error))
		{
			$start_day = $_POST['start_day'];
			$start_month = $_POST['start_month'];
			$start_year = $_POST['start_year'];
			$start_time = mktime(0, 0, 0, $start_month, $start_day, $start_year);

			$evaluation->setStartDate($start_time);

			$stop_day = $_POST['stop_day'];
			$stop_month = $_POST['stop_month'];
			$stop_year = $_POST['stop_year'];
			$stop_time = mktime(23, 59, 59, $stop_month, $stop_day, $stop_year);

			$evaluation->setStopDate($stop_time);

			$evaluation->save();

			$this->parent->parent->reportSuccess('Evaluation wurde editiert');
			$this->displayHeader('show_institute');
			$this->show_institute($evaluation->getInstitutId());
		}
		else
		{
			$this->parent->parent->reportError($error);
			$this->evaluation_details($evaluation_id);
		}
	}

	/**
	 * Zeigt einen berblick aller Evaluationen gruppiert nach Fakultten an.
	 * @uses ibit_Evaluation::getExpiredEvaluationsFacultyOverview()
	 * @uses ibit_Evaluation::getCurrentEvaluationsFacultyOverview()
	 * @uses ibit_Evaluation::getFutureEvaluationsFacultyOverview()
	 */
	function show_overview()
	{
		$evaluations = array();
		$evaluation_count = array('expired'=>0, 'current'=>0, 'future'=>0);
		if ($_SESSION['show_expired'])
		{
			$evals = ibit_Evaluation::getExpiredEvaluationsFacultyOverview($_SESSION['semester_id']);
			foreach ($evals as $eval)
			{
				if (empty($evaluations[$eval['fakultaet_id']]))
				{
					$data = $eval;
					$data['expired_count'] = $eval['evaluation_count'];
					$data['current_count'] = 0;
					$data['future_count'] = 0;
					$evaluations[$eval['fakultaet_id']] = $data;
				}
				else
				{
					$evaluations[$eval['fakultaet_id']]['expired_count'] += $eval['evaluation_count'];
					$evaluations[$eval['fakultaet_id']]['seminar_count'] += $eval['seminar_count'];
					$evaluations[$eval['fakultaet_id']]['seminar_members'] += $eval['seminar_members'];
					$evaluations[$eval['fakultaet_id']]['institute_count'] += $eval['institute_count'];
					$evaluations[$eval['fakultaet_id']]['evaluation_count'] += $eval['evaluation_count'];
					$evaluations[$eval['fakultaet_id']]['participants'] += $eval['participants'];
				}
				$evaluation_count['expired'] += $eval['evaluation_count'];
			}
		}
		if ($_SESSION['show_current'])
		{
			$evals = ibit_Evaluation::getCurrentEvaluationsFacultyOverview($_SESSION['semester_id']);
			foreach ($evals as $eval)
			{
				if (empty( $evaluations[$eval['fakultaet_id']]))
				{
					$data = $eval;
					$data['expired_count'] = 0;
					$data['current_count'] = $eval['evaluation_count'];
					$data['future_count'] = 0;
					$evaluations[$eval['fakultaet_id']] = $data;
				}
				else
				{
					$evaluations[$eval['fakultaet_id']]['current_count'] += $eval['evaluation_count'];
					$evaluations[$eval['fakultaet_id']]['seminar_count'] += $eval['seminar_count'];
					$evaluations[$eval['fakultaet_id']]['seminar_members'] += $eval['seminar_members'];
					$evaluations[$eval['fakultaet_id']]['institute_count'] += $eval['institute_count'];
					$evaluations[$eval['fakultaet_id']]['evaluation_count'] += $eval['evaluation_count'];
					$evaluations[$eval['fakultaet_id']]['participants'] += $eval['participants'];
				}
				$evaluation_count['current'] += $eval['evaluation_count'];
			}
		}
		if ($_SESSION['show_future'])
		{
			$evals = ibit_Evaluation::getFutureEvaluationsFacultyOverview($_SESSION['semester_id']);
			foreach ($evals as $eval)
			{
				if (empty($evaluations[$eval['fakultaet_id']]))
				{
					$data = $eval;
					$data['expired_count'] = 0;
					$data['current_count'] = 0;
					$data['future_count'] = $eval['evaluation_count'];
					$evaluations[$eval['fakultaet_id']] = $data;
				}
				else
				{
					$evaluations[$eval['fakultaet_id']]['future_count'] += $eval['evaluation_count'];
					$evaluations[$eval['fakultaet_id']]['seminar_count'] += $eval['seminar_count'];
					$evaluations[$eval['fakultaet_id']]['seminar_members'] += $eval['seminar_members'];
					$evaluations[$eval['fakultaet_id']]['institute_count'] += $eval['institute_count'];
					$evaluations[$eval['fakultaet_id']]['evaluation_count'] += $eval['evaluation_count'];
					$evaluations[$eval['fakultaet_id']]['participants'] += $eval['participants'];
				}
				$evaluation_count['future'] += $eval['evaluation_count'];
			}
		}

		$template = $this->parent->parent->getTemplate('admin_evaluation_administration_over_view');

		$template->set_attribute('visible_count', DBManager::Get()->query("SELECT COUNT(*) FROM ibit_evaluation WHERE visible_date IS NOT NULL AND semester_id = '{$_SESSION['semester_id']}'")->fetchColumn());

		$template->set_attribute('comments_count', DBManager::Get()->query("SELECT COUNT(*) FROM ibit_evaluation WHERE comment IS NOT NULL AND semester_id = '{$_SESSION['semester_id']}'")->fetchColumn());

		$template->set_attribute('guilty_count', DBManager::Get()->query("SELECT COUNT(*) FROM (SELECT COUNT( u.evaluation_id ) AS count_guilty FROM ibit_evaluation_user AS u INNER JOIN ibit_evaluation AS e USING ( evaluation_id ) WHERE e.semester_id = '{$_SESSION['semester_id']}' GROUP BY u.evaluation_id HAVING SUM( u.hidden <>1 ) >= ".ibit_EvaluationConfig::GetConfig('evaluation', 'min_users').") AS temp")->fetchColumn());

		foreach ( $evaluations as $faculty_id=>$faculty_data )
		{
			$evaluations[$faculty_id]['institute_total_count'] = ibit_Helper::getInstituteCountByFacultyId($faculty_id);
			$evaluations[$faculty_id]['seminar_total_count'] = ibit_Helper::getSeminarCountByFacultyId($faculty_id, $_SESSION['semester_id']);
		}

		$template->set_attribute('evaluation_data', $evaluations);
		$evaluation_count['total'] = array_sum($evaluation_count);
		$template->set_attribute('evaluation_count', $evaluation_count);
		$template->set_attribute('link_faculty_detail', $this->parent->base_link.'&command=show_faculty');

		echo $template->render();
	}

	/**
	 * Zeigt einen berblick aller Evaluationen einer Fakultt gruppiert nach Instituten an.
	 * @param string $faculty_id Id der Fakultt
	 * @uses ibit_Evaluation::getExpiredEvaluationsByFacultyId()
	 * @uses ibit_Evaluation::getCurrentEvaluationsByFacultyId()
	 * @uses ibit_Evaluation::getFutureEvaluationsByFacultyId()
	 */
	function show_faculty($faculty_id, $fakview=false)
	{
		$evaluation_count = array('expired'=>0, 'current'=>0, 'future'=>0);

		$evaluations = array();
		if ($_SESSION['show_expired'])
		{
			$evals = ibit_Evaluation::getExpiredEvaluationsByFacultyId($faculty_id, $_SESSION['semester_id']);
			foreach ($evals as $eval)
			{
				if (empty($evaluations[$eval['institut_id']]))
				{
					$data = $eval;
					$data['expired_count'] = $eval['evaluation_count'];
					$data['current_count'] = 0;
					$data['future_count'] = 0;
					$evaluations[$eval['institut_id']] = $data;
				}
				else
				{
					$evaluations[$eval['institut_id']]['expired_count'] += $eval['evaluation_count'];
					$evaluations[$eval['institut_id']]['evaluation_count'] += $eval['evaluation_count'];
					$evaluations[$eval['institut_id']]['seminar_count'] += $eval['seminar_count'];
					$evaluations[$eval['institut_id']]['seminar_members'] += $eval['seminar_members'];
					$evaluations[$eval['institut_id']]['participants'] += $eval['participants'];
				}
				$evaluation_count['expired'] += $eval['evaluation_count'];
			}
		}
		if ($_SESSION['show_current'])
		{
			$evals = ibit_Evaluation::getCurrentEvaluationsByFacultyId($faculty_id, $_SESSION['semester_id']);
			foreach ($evals as $eval)
			{
				if (empty($evaluations[$eval['institut_id']]))
				{
					$data = $eval;
					$data['expired_count'] = 0;
					$data['current_count'] = $eval['evaluation_count'];
					$data['future_count'] = 0;
					$evaluations[$eval['institut_id']] = $data;
				}
				else
				{
					$evaluations[$eval['institut_id']]['current_count'] += $eval['evaluation_count'];
					$evaluations[$eval['institut_id']]['evaluation_count'] += $eval['evaluation_count'];
					$evaluations[$eval['institut_id']]['seminar_count'] += $eval['seminar_count'];
					$evaluations[$eval['institut_id']]['seminar_members'] += $eval['seminar_members'];
					$evaluations[$eval['institut_id']]['participants'] += $eval['participants'];
				}
				$evaluation_count['current'] += $eval['evaluation_count'];
			}
		}
		if ($_SESSION['show_future'])
		{
			$evals = ibit_Evaluation::getFutureEvaluationsByFacultyId($faculty_id, $_SESSION['semester_id']);
			foreach ($evals as $eval)
			{
				if (empty($evaluations[$eval['institut_id']]))
				{
					$data = $eval;
					$data['expired_count'] = 0;
					$data['current_count'] = 0;
					$data['future_count'] = $eval['evaluation_count'];
					$evaluations[$eval['institut_id']] = $data;
				}
				else
				{
					$evaluations[$eval['institut_id']]['future_count'] += $eval['evaluation_count'];
					$evaluations[$eval['institut_id']]['evaluation_count'] += $eval['evaluation_count'];
					$evaluations[$eval['institut_id']]['seminar_count'] += $eval['seminar_count'];
					$evaluations[$eval['institut_id']]['seminar_members'] += $eval['seminar_members'];
					$evaluations[$eval['institut_id']]['participants'] += $eval['participants'];
				}
				$evaluation_count['future'] += $eval['evaluation_count'];
			}
		}

		$template = $this->parent->parent->getTemplate($fakview?'fakadmin_faculty_view':'admin_evaluation_administration_faculty_view');

		// Anzahl freigeschalteter Evals ausgeben
		$template->set_attribute('visible_count', DBManager::Get()->query("SELECT COUNT(*) FROM ibit_evaluation WHERE visible_date IS NOT NULL AND fakultaet_id = '{$faculty_id}' AND semester_id = '{$_SESSION['semester_id']}'")->fetchColumn());

		// Anzahl kommentierter Evals ausgeben
		$template->set_attribute('comments_count', DBManager::Get()->query("SELECT COUNT(*) FROM ibit_evaluation WHERE comment IS NOT NULL AND fakultaet_id = '{$faculty_id}' AND semester_id = '{$_SESSION['semester_id']}'")->fetchColumn());

		// Anzahl gltiger Evals
		$template->set_attribute('guilty_count', DBManager::Get()->query("SELECT COUNT(*) FROM (SELECT COUNT( u.evaluation_id ) AS count_guilty FROM ibit_evaluation_user AS u INNER JOIN ibit_evaluation AS e USING ( evaluation_id ) WHERE fakultaet_id = '{$faculty_id}' AND e.semester_id = '{$_SESSION['semester_id']}' GROUP BY u.evaluation_id HAVING SUM( u.hidden <>1 ) >= ".ibit_EvaluationConfig::GetConfig('evaluation', 'min_users').") AS temp")->fetchColumn());

		foreach ($evaluations as $institute_id=>$institute_data)
		{
			$evaluations[$institute_id]['seminar_total_count'] = ibit_Helper::getSeminarCountByInstituteId($institute_id, $_SESSION['semester_id']);
		}

		$evaluation_count['total'] = array_sum($evaluation_count);
		$template->set_attribute('evaluation_count', $evaluation_count);
		$template->set_attribute('evaluation_data', $evaluations);
		$template->set_attribute('link_institute_detail', $this->parent->base_link.'&command=show_institute');
		$template->set_attribute('link_delete', $this->parent->base_link.'&command=show_faculty&faculty_id='.$faculty_id.'&action=delete_evaluations_by_institute_ids');
		$template->set_attribute('link_back', $this->parent->base_link.'&command=show_faculties');
		echo $template->render();
	}

	/**
	 * Zeigt einen berblick aller Evaluationen eines Instituts an.
	 * @param string $institute_id Id des Instituts
	 * @uses ibit_Evaluation::getExpiredEvaluationsByInstituteId()
	 * @uses ibit_Evaluation::getCurrentEvaluationsByInstituteId()
	 * @uses ibit_Evaluation::getFutureEvaluationsByInstituteId()
	 */
	function show_institute( $institute_id, $fakview=false )
	{
		$skip = (!empty($_REQUEST['skip']) and ($_SESSION['evaladmin_maxrows']!=-1) ) ? $_REQUEST['skip'] : 0;
		$limit = $_SESSION['evaladmin_maxrows'] == -1 ? 100000000 : $_SESSION['evaladmin_maxrows'];

		$tmp_skip = $skip;
		$tmp_limit = $limit;
		$total_count = 0;
		$count = 0;

		$evaluation_data = Array();
		if ($_SESSION['show_expired'])
		{
			$evaluation_temp_data = ibit_Evaluation::getExpiredEvaluationsByInstituteId($institute_id, $tmp_skip, $tmp_limit, $count, $_SESSION['semester_id']);
			$evaluation_data = array_merge($evaluation_data,  $evaluation_temp_data);
			$total_count += $count;
		}
		if ($_SESSION['show_current'])
		{
			$evaluation_temp_data = ibit_Evaluation::getCurrentEvaluationsByInstituteId($institute_id, $tmp_skip, $tmp_limit, $count, $_SESSION['semester_id']);
			$evaluation_data = array_merge($evaluation_data, $evaluation_temp_data);
			$total_count += $count;
		}
		if ($_SESSION['show_future'])
		{
			$evaluation_temp_data = ibit_Evaluation::getFutureEvaluationsByInstituteId($institute_id, $tmp_skip, $tmp_limit, $count, $_SESSION['semester_id']);
			$evaluation_data = array_merge($evaluation_data, $evaluation_temp_data);
			$total_count += $count;
		}

		$template = $this->parent->parent->getTemplate($fakview?'fakadmin_institute_view':'admin_evaluation_administration_institute_view');

		// Anzahl freigeschalteter Evals ausgeben
		$template->set_attribute('visible_count', DBManager::Get()->query("SELECT COUNT(*) FROM ibit_evaluation WHERE visible_date IS NOT NULL AND institut_id = '{$institute_id}' AND semester_id = '{$_SESSION['semester_id']}'")->fetchColumn());

		// Anzahl kommentierter Evals ausgeben
		$template->set_attribute('comments_count', DBManager::Get()->query("SELECT COUNT(*) FROM ibit_evaluation WHERE comment IS NOT NULL AND institut_id = '{$institute_id}' AND semester_id = '{$_SESSION['semester_id']}'")->fetchColumn());

		// Anzahl gltiger Evals
		$template->set_attribute('guilty_count', DBManager::Get()->query("SELECT COUNT(*) FROM (SELECT COUNT( u.evaluation_id ) AS count_guilty FROM ibit_evaluation_user AS u INNER JOIN ibit_evaluation AS e USING ( evaluation_id ) WHERE institut_id = '{$institute_id}' AND e.semester_id = '{$_SESSION['semester_id']}' GROUP BY u.evaluation_id HAVING SUM( u.hidden <>1 ) >= ".ibit_EvaluationConfig::GetConfig('evaluation', 'min_users').") AS temp")->fetchColumn());

		if ($total_count>0 and $skip >= $total_count)
		{
			while ($skip>=$total_count)
			{
				$skip -= $limit;
			}

			$tmp_skip = $skip;
			$tmp_limit = $limit;

			$evaluation_data = array();
			if ($_SESSION['show_expired'])
			{
				$evaluation_temp_data = ibit_Evaluation::getExpiredEvaluationsByInstituteId($institute_id, $tmp_skip, $tmp_limit, $count, $_SESSION['semester_id']);
				$evaluation_data = array_merge($evaluation_data,  $evaluation_temp_data);
			}
			if ($_SESSION['show_current'])
			{
				$evaluation_temp_data = ibit_Evaluation::getCurrentEvaluationsByInstituteId($institute_id, $tmp_skip, $tmp_limit, $count, $_SESSION['semester_id']);
				$evaluation_data = array_merge($evaluation_data, $evaluation_temp_data);
			}
			if ($_SESSION['show_future'])
			{
				$evaluation_temp_data = ibit_Evaluation::getFutureEvaluationsByInstituteId($institute_id, $tmp_skip, $tmp_limit, $count, $_SESSION['semester_id']);
				$evaluation_data = array_merge($evaluation_data, $evaluation_temp_data);
			}
		}

		if ($total_count<=0)
		{
			$skip = 0;
		}

		$evaluation_data_grouped = array();
		foreach ($evaluation_data as $eval)
		{
			if (!isset($evaluation_data_grouped[$eval['template_id']]))
			{
				$item = array();
				$item['template_id'] = $eval['template_id'];
				$item['template_title'] = $eval['evaluation_title'];
				$item['evaluations'] = array();

				$evaluation_data_grouped[$eval['template_id']] = $item;
			}
			array_push($evaluation_data_grouped[$eval['template_id']]['evaluations'], $eval);
		}

		$template->set_attribute('institute_view', true);
		$template->set_attribute('evaluation_data', $evaluation_data_grouped);
		$template->set_attribute('link_back', $this->parent->base_link.'&command=show_faculty&faculty_id='.ibit_Helper::getFacultyForInstitute($institute_id));
		$template->set_attribute('link_delete', $this->parent->base_link.'&command=show_institute&institute_id='.$institute_id.'&action=delete_evaluations&skip='.$skip);
		$template->set_attribute('link_edit', $this->parent->base_link.'&command=evaluation_details&skip='.$skip);
		$template->set_attribute('link_page_back', $this->parent->base_link.'&command=show_institute&institute_id='.$institute_id.'&skip='.($skip-$limit));
		$template->set_attribute('link_page_next', $this->parent->base_link.'&command=show_institute&institute_id='.$institute_id.'&skip='.($skip+$limit));
		$template->set_attribute('skip', $skip);
		$template->set_attribute('total_count', $total_count);
		echo $template->render();
	}
}
?>