<?php
/**
 * classes/ibit_EvaluationTemplate.class.php
 *
 * @author  Michael Riehemann <michael.riehemann@uni-oldenburg.de>
 * @author  Jan-Hendrik Willms <tleilax@mindfuck.de>
 * @author  Ivn Marcos <ivan.marcos@gmx.net>
 * @author  Nico Mueller <nico.mueller@uni-oldenburg.de>
 * @package IBIT_Evaluation
 * @copyright IBIT 2006-2008
 * @version 2.0.15
 */

/**
 * Die Reprsentation einer Evaluationsvorlage
 *
 * Diese Klasse stellt die Reprsentation der Daten einer Evaluationsvorlage dar. Es werden Funktionen zum Laden, Speichern
 * und Bearbeiten der Daten einer Vorlage angeboten.
 *
 * @author     Jan-Hendrik Willms <tleilax@mindfuck.de>
 * @author     Michael Riehemann <michael.riehemann@uni-oldenburg.de>
 * @author     Ivn Marcos <ivan.marcos@gmx.net>
 * @package    IBIT_Evaluation
 * @subpackage Structure
 * @copyright  Copyright 2006, 2007 IBIT
 * @version    1.1
 */
class ibit_EvaluationTemplate
{
	/**
	 * Die ID der Evaluationsvorlage
	 * @var int $template_id
	 */
	var $template_id = null;

	/**
	 * Der Titel der Evaluationsvorlage
	 * @var string $title
	 */
	var $title;

	/**
	 * Die Beschreibung der Evaluationsvorlage
	 * @var string $description
	 */
	var $description;

	/**
	 * Das Datum der letzten nderung der Evaluationsvorlage
	 * @var int $change_date
	 */
	var $change_date;

	/**
	 * Der Status der Evaluationsvorlage
	 * @var int $status
	 */
	var $status;

	/**
	 * Gibt an, ob die Evaluationsvorlage vor nderungen geschtzt ist
	 * @var int $protected
	 */
	var $protected;

	/**
	 * Die Id des Autors der Evaluationsvorlage
	 * @var string $author_id
	 */
	var $author_id;

	/**
	 * Der Name des Autors der Evaluationsvorlage
	 * @var string $autor_name
	 */
	var $author_name;

	/**
 	 * Array, das die Gruppen der Evaluationsvorlage enthlt
	 * @var array $groups
	 */
	var $groups = Array();

	/**
	 * Der Konstruktor der Klasse.
	 * @param int $id Id der zu ladenden Evaluationsvorlage
	 */
	function ibit_EvaluationTemplate( $id = null )
	{
		if ( $id !== null )
		{
			$this->load( $id );
		}
	}

	/**
	 * Ldt eine Evaluationsvorlage anhand der bergebenen Id.
	 * @param int $id Id der Evaluationsvorlage
	 * @return boolean Gibt an, ob das Laden erfolgreich war
	 */
	function load( $id )
	{
		$row = DBManager::Get()->query("SELECT evaluation_template_id, title, description, change_date, status, protected, author_id, CONCAT(Vorname, ' ', Nachname) AS author_name FROM ibit_evaluation_templates AS t LEFT JOIN auth_user_md5 AS u ON (t.author_id  = u.user_id) WHERE evaluation_template_id = '{$id}'")->fetch(PDO::FETCH_ASSOC);
		if (!$row)
		{
			return false;
		}

		$this->template_id = $id;
		$this->title = $row['title'];
		$this->description = $row['description'];
		$this->change_date = $row['change_date'];
		$this->status = $row['status'];
		$this->protected = $row['protected'];
		$this->author_id = $row['author_id'];
		$this->author_name = $row['author_name'];

		$this->loadStructure();

		return true;
	}

	/**
	 * Speichert die Evaluationsvorlage in der Datenbank.
	 */
	function save()
	{
		$result = DBManager::Get()->exec("INSERT INTO ibit_evaluation_templates (evaluation_template_id, title, description, change_date, status, protected, author_id) VALUES ('{$this->template_id}', '{$this->title}', '{$this->description}', NOW(), '{$this->status}', '{$this->protected}', '{$this->author_id}') ON DUPLICATE KEY UPDATE title=VALUES(title), description=VALUES(description), change_date=VALUES(change_date), status=VALUES(status), protected=VALUES(protected), author_id=VALUES(author_id)");
		if ($result and $this->template_id === null)
		{
			$this->template_id = DBManager::Get()->lastInsertId();
		}
	}

	/**
	 * Lscht eine Evaluationsvorlage und smtliche Querverweise aus der Datenbank.
	 * @param int $template_id Id der Evaluationsvorlage
	 * @return boolean Gibt an, ob das Lschen erfolgreich war
	 * @static
	 */
	function delete( $template_id )
	{
		DBManager::Get()->exec("DELETE FROM ibit_evaluation_templates WHERE evaluation_template_id='{$template_id}' AND protected = 0");
		DBManager::Get()->exec("DELETE FROM ibit_evaluation_links WHERE evaluation_template_id='{$template_id}'");

		# herrenlose fragen und antworten lschen
		# Fehlermeldung: SQLSTATE[HY000]: General error: 1093 
		# You can't specify target table 'ibit_evaluation_group_templates' for update in FROM clause
		#DBManager::Get()->exec("DELETE QUICK FROM ibit_evaluation_group_templates WHERE evaluation_group_template_id IN (SELECT t.evaluation_group_template_id AS group_id FROM ibit_evaluation_group_templates AS t LEFT JOIN ibit_evaluation_links AS l USING( evaluation_group_template_id ) WHERE l.evaluation_template_id IS NULL)");
		#DBManager::Get()->exec("DELETE QUICK FROM ibit_evaluation_question_templates WHERE evaluation_question_template_id IN (SELECT t.evaluation_question_template_id AS question_id FROM ibit_evaluation_question_templates AS t LEFT JOIN ibit_evaluation_links AS l USING( evaluation_question_template_id ) WHERE l.evaluation_template_id IS NULL)");

		# SQLSTATE[HY000]: General error: 2014 
		# Cannot execute queries while other unbuffered queries are active. 
		# Consider using PDOStatement::fetchAll(). Alternatively, if your code is 
		# only ever going to run against mysql, you may enable query buffering by 
		# setting the PDO::MYSQL_ATTR_USE_BUFFERED_QUERY attribute.
		#DBManager::Get()->exec("OPTIMIZE TABLE ibit_evaluation_templates, ibit_evaluation_links");

		return true;
	}

	/**
	 * Setzt den Titel der Evaluationsvorlage.
	 * @param string $title Titel der Evaluationsvorlage
	 */
	function setTitle( $title )
	{
		$this->title = $title;
	}

	/**
	 * Liefert den Titel der Evaluationsvorlage zurck.
	 * @return string Titel der Evaluationsvorlage
	 */
	function getTitle()
	{
		return $this->title;
	}

	/**
	 * Setzt die Beschreibung der Evaluationsvorlage.
	 * @param string $description Beschreibung der Evaluationsvorlage
	 */
	function setDescription( $description )
	{
		$this->description = $description;
	}

	/**
	 * Liefert die Beschreibung der Evaluationsvorlage zurck.
	 * @return string Beschreibung der Evaluationsvorlage
	 */
	function getDescription()
	{
		return $this->description;
	}

	/**
	 * Setzt die Id der Evaluationsvorlage.
	 * @param int $status Id der Evaluationsvorlage
	 */
	function setTemplateID( $id )
	{
		$this->template_id = $id;
	}

	/**
	 * Liefert die Id der Evaluationsvorlage zurck.
	 * @return int Id der Evaluationsvorlage
	 */
	function getTemplateID()
	{
		return $this->template_id;
	}

	/**
	 * Setzt den Status der Evaluationsvorlage.
	 * @param int $status Status der Evaluationsvorlage
	 */
	function setStatus( $status )
	{
		$this->status = $status;
	}

	/**
	 * Liefert den Status der Evaluationsvorlage zurck.
	 * @return int Status der Vorlage
	 */
	function getStatus()
	{
		return $this->status;
	}

	/**
	 * Setzt das Protected-Flag der Evaluationsvorlage.
	 * @param boolean $protected Protected-Flag der Evaluationsvorlage
	 */
	function setProtected( $protected = 1 )
	{
		$this->protected = $protected;
	}

	/**
	 * Liefert das Protected-Flag der Evaluationsvorlage zurck.
	 * @return boolean Protected-Flag der Evaluationsvorlage
	 */
	function getProtected()
	{
		return $this->protected;
	}

	/**
	 * Setzt die Id des Autoren der Evaluationsvorlage
	 * @param string $author_id Id des Autoren
	 */
	function setAuthorId( $author_id )
	{
		$this->author_id = $author_id;
	}

	/**
	 * Liefert die Id des Autoren der Evaluationsvorlage zurck.
	 * @return string Id des Autoren
	 */
	function getAuthorId()
	{
		return $this->author_id;
	}

	/**
	 * Liefert den Namen des Autoren der Evaluationsvorlage zurck.
	 * @return string Name des Autoren
	 */
	function getAuthorName()
	{
		return $this->author_name;
	}

	/**
	 * Fgt eine Gruppe der Evaluationsvorlage hinzu.
	 * Es wird verhindert, dass zwei identische Gruppen vorhanden sind.
	 * @param object $group_object Gruppenobjekt, das der Evaluationsvorlage hinzugefgt werden soll
	 */
	function addGroup( $group_object )
	{
		$found = false;
		if ( $group_object->getId() !== null )
		{
			foreach ( $this->groups as $group_index => $group )
			{
				if ( $group->getId() == $group_object->getId() )
				{
					$found = true;
					$this->groups[ $group_index ] = $group_object;
					break;
				}
			}
		}
		if ( !$found )
		{
			array_push( $this->groups, $group_object );
		}
	}

	/**
	 * Entfernt eine Gruppe aus der Evaluationsvorlage.
	 * @param object $group_object Gruppenobjekt, das aus der Evaluationsvorlage entfernt werden soll
	 */
	function removeGroup( $group_object )
	{
		foreach ( $this->groups as $group_index => $group )
		{
			if ( $group_object->getEvaluationGroupId() == $group->getEvaluationGroupId() )
			{
				unset( $this->groups[ $group_index ] );
			}
		}
	}

	/**
	 * Ldt die komplette Struktur der Evaluationsvorlage aus der Datenbank.
	 * @return boolean Gibt an, ob das Laden erfolgreich war
	 * @uses ibit_EvaluationGroup
	 * @uses ibit_EvaluationQuestion
	 * @todo Bei dieser Funktion wre zu berlegen, sie neu zu schreiben und smtliche Queries hier auszufhren, um den SQL-Traffic auf
	 *       4 Queries im besten Fall zu reduzieren.
	 */
	function loadStructure()
	{
		$groups_loaded = array();
		$this->groups = array();

		$rows = DBManager::Get()->query("SELECT evaluation_group_template_id, group_position, evaluation_question_template_id, question_position FROM ibit_evaluation_links WHERE evaluation_template_id = '{$this->template_id}' ORDER BY group_position ASC, question_position ASC")->fetchAll(PDO::FETCH_ASSOC);
		if (empty($rows))
		{
			return false;
		}
		
		$group = null;
		foreach ($rows as $row)
		{
			if (!in_array($row['evaluation_group_template_id'], $groups_loaded))
			{
				array_push($groups_loaded, $row['evaluation_group_template_id']);

				if ( $group !== null )
				{
					array_push($this->groups, $group);
				}
				$group = new ibit_EvaluationGroup($row['evaluation_group_template_id']);
				$group->setPosition( $row['group_position'] );
			}

			$question = new ibit_EvaluationQuestion($row['evaluation_question_template_id']);
			$question->setPosition($row['question_position']);
			$question->loadAnswers();
			$group->addQuestion($question);
		}

		array_push($this->groups, $group);
		

		return true;
	}

	/**
	 * Speichert die Struktur der Evaluationsvorlage in der Datenbank.
	 */
	function storeStructure()
	{
		if ( $this->template_id === null )
		{
			$this->save();
		}
		DBManager::Get()->exec("DELETE FROM ibit_evaluation_links WHERE evaluation_template_id = '{$this->template_id}'");

		foreach ($this->groups as $group)
		{
			$group->save();

			foreach ( $group->questions as $question )
			{
				$question->save();

				DBManager::Get()->exec("INSERT INTO ibit_evaluation_links (evaluation_template_id, evaluation_group_template_id, group_position, evaluation_question_template_id, question_position) VALUES ('{$this->template_id}', '{$group->getId()}', '{$group->getPosition()}', '{$question->getId()}', '{$question->getPosition()}')");
			}
		}
	}

	/**
	 * Bricht das Objekt der Evaluationsvorlage in ein Array auf.
	 * Die Rckgabe sieht dabei folgendermassen aus:<br/>
	 * <pre>
	 *    [
	 *     id          => Id der Evaluationsvorlage,
	 *     title       => Titel der Evaluationsvorlage,
	 *     description => Beschreibung der Evaluationsvorlage,
	 *     status      => Status der Evaluationsvorlage,
	 *     change_date => nderungsdatum der Evaluationsvorlage,
	 *     protected   => Gibt an, ob die Evaluationsvorlage vor Vernderungen geschtzt ist,
	 *     author_id   => Id des Autoren der Evaluationsvorlage,
	 *     author_name => Name des Autoren der Evaluationsvorlage,
	 *     groups      => [
	 *       ...
	 *                    ]{0..x}
	 *    ]
	 * </pre>
	 *
	 * @return array Evaluationsvorlagendaten
	 * @see ibit_EvaluationGroup::flattenToArray()
	 */
	function flattenToArray()
	{
		$result = Array();
		$result['id'] = $this->template_id;
		$result['title'] = $this->title;
		$result['description'] = $this->description;
		$result['status'] = $this->status;
		$result['change_date'] = $this->change_date;
		$result['protected'] = $this->protected;
		$result['author_id'] = $this->author_id;
		$result['author_name'] = $this->author_name;

		$result['groups'] = Array();
		foreach ( $this->groups as $group )
		{
			//Nur Wenn es auch Gruppen gibt...
			if(!empty($group))
			{
				array_push( $result['groups'], $group->flattenToArray() );
			}
		}
		return $result;
	}

##########################
## STATISCHE FUNKTIONEN ##
##########################

	/**
	 * Ldt Infos ber alle vorhandenen Evaluationen aus der Datenbank.
	 * Die Rckgabe sieht dabei folgendermassen aus:
	 *    [
	 *     id          => Id der Evaluationsvorlage,
	 *     title       => Titel der Evaluationsvorlage,
	 *     description => Beschreibung der Evaluationsvorlage,
	 *     status      => Status der Evaluationsvorlage,
	 *     change_date => nderungsdatum der Evaluationsvorlage,
	 *     protected   => Gibt an, ob die Evaluationsvorlage vor Vernderungen geschtzt ist,
	 *     author_id   => Id des Autoren der Evaluationsvorlage,
	 *     author_name => Name des Autoren der Evaluationsvorlage
	 *    ]{0..x}
	 *
	 * @param boolean $active Gibt an, ob nur aktive Evaluationsvorlagen geladen werden sollen
	 * @return array Evaluationsvorlagendaten
	 * @static
	 */
	static function getTemplatesInfo( $active = false )
	{
		return DBManager::Get()->query("SELECT evaluation_template_id AS id, title, description, change_date, author_id, status, protected, CONCAT(Vorname, ' ', Nachname) AS author_name FROM ibit_evaluation_templates AS t LEFT JOIN auth_user_md5 AS u ON (t.author_id COLLATE latin1_general_ci = u.user_id COLLATE latin1_general_ci)".($active?" WHERE t.status = 1":""))->fetchAll(PDO::FETCH_ASSOC);
	}
}
?>