<?php
/**
 * classes/ibit_Graphics.class.php
 *
 * @author  Michael Riehemann <michael.riehemann@uni-oldenburg.de>
 * @author  Jan-Hendrik Willms <tleilax@mindfuck.de>
 * @author  Ivn Marcos <ivan.marcos@gmx.net>
 * @author  Nico Mueller <nico.mueller@uni-oldenburg.de>
 * @package IBIT_Evaluation
 * @copyright Copyright 2006, 2007 IBIT
 * @version 1.3
 */

/**
 *
 *
 * @author     Michael Riehemann <michael.riehemann@uni-oldenburg.de>
 * @package    IBIT_Evaluation
 * @subpackage Structure
 * @copyright  Copyright 2006, 2007 IBIT
 * @version    1.3
 *
*/
class ibit_Graphics {

	var $path;
	var $evaluation_id;
	var $name;
	var $width = 300;
	var $height = 230;
	var $type = 'png';
	var $shading = 0;

	/**
     * Konstruktor
     *
     * @param string $path - Pfad zum Bilderverzeichnis
     * @param array $settings - Werte fr die Grafiken (Typ, Gre etc.)
     * @return de_celab_EvaluationGraphics
     */
    function ibit_Graphics($evaluation_id, $width, $height, $type, $shading)
    {
    	$this->path = $GLOBALS['ibit_eval_imagepath'];
    	$this->evaluation_id = $evaluation_id;
    	$this->width = $width;
    	$this->height = $height;
    	$this->type =  $type;
    	$this->shading = $shading;
    }

    /**
     *  Allgemeine Funktion zum Erstellen einer Grafik
     *
     * @param array $answers - Antworten-Array eines Fragenblockes
     * @param array $type - Umfragetyp (polskala, multiplchoice, likertskala)
     * @param string $id - ID der Frage
     * @param int $total - Anzahl Antworten
     * @param int $charttype - 0=Balkendiagramm, 1= Tortendiagramm
     * @param string $text - Text fr die Bildunterschrift
     */
    function createImage($question)
    {
    	$this->name = md5($this->evaluation_id."_".$question['question_id']."_".$question['position']."_".$question['chart_type']);

    	# /image-Pfad im Tempverzeichnis anlegen, falls er nicht existiert
		if ( !( is_dir( $this->path ) or @mkdir( $this->path ) ) )
		{
			$this->template->append( 'messages_errors', 'Fehler beim Erstellen der Grafiken, da Grafik-Verzeichnis nicht vorhanden ist oder erstellt werden kann.');
			return;
		}

 		# Neue Grafiken nur erstellen, falls diese noch fehlen
 		if(is_file($this->path.$this->name) && EVAL_FORCE < 1 )
		{
			return;
		}
		else
		{
	    	require_once( $GLOBALS['ibit_eval_classpath'].'libs/phplot/phplot.php' );
	    	if($question['chart_type'] == 0)
	    	{
	    		$this->createBars($question);
	    	}
	    	elseif($question['chart_type'] == 1)
	    	{
	    		$this->createPie($question);
	    	}
	    	else
	    	{
	    		$this->template->append( 'messages_errors', 'Fehler beim Erstellen der Grafik, kein Diagrammtyp ausgewhlt.');
	    		return;
	    	}
		}
    }

    /**
     * Ein Balkendiagramm erzeugen
	 */
    function createBars($question)
    {
	    	#Variablen
	    	$length = 0;
	    	$legend = array();
	    	$data = array($question['title']);
	    	$max = 0;

	    	#Legende erzeugen
	    	foreach($question['answers'] as $answer)
	    	{
	    		$length++;
	    		$data = array_merge($data, array($answer['count']));
	    		if(!empty($answer['ratio']))
	    		{
	    			array_push($legend, $length." (".round($answer['ratio'])."%)");
	    		}
	    		else
	    		{
	    			array_push($legend, $length." (0%)");
	    		}
	    		if($max < $answer['count'])
	    		{
	    			$max = $answer['count'];
	    		}
	    	}
	    	$data2 = array($data);

	    	#Grafik erzeugen
	    	$bars = new PHPlot($this->width,$this->height);
			$bars->SetPlotType('bars');
			$bars->SetDataType('text-data');
			$bars->SetDataValues($data2);
			$bars->SetShading($this->shading);
			$bars->SetLegend($legend);
			if($length >= 10)
			{
				$bars->SetFont('legend', null, 1);
			}
			$bars->SetLegendPixels(220, 5);
			$bars->SetDataBorderColors('black');
			$bars->SetImageBorderColor('black');
			$bars->SetImageBorderType('plain');
			$bars->SetDataColors($this->setColor($question['html_type']), 'black');
			$bars->SetMarginsPixels(25, 45, 5, 20);
			$bars->SetXTickLabelPos('none');
			$bars->SetXTickPos('none');
			$bars->SetYTickIncrement($this->setYTickIncrement($max));

			#Dateiformat
			$bars->SetFileFormat($this->type);

			#Ausgabe in Datei
			$bars->SetIsInline(TRUE);
			$bars->SetOutputFile($this->path.$this->name.".".$this->type);
			$bars->DrawGraph();
	}

	# Ein Tortendiagramm erzeugen
    function createPie($question)
    {
	    	#Variablen
	    	$length = 0;
	    	$data = array('');

	    	#Berechnung
	    	foreach($question['answers'] as $answer)
	    	{
	    		$length++;
	    		$data = array_merge($data, array($answer['count']));
	    	}
			$data2 = array($data);

			#Grafik erzeugen
	    	$pie = new PHPlot($this->width,$this->height);
			$pie->SetImageBorderColor('black');
			$pie->SetImageBorderType('plain');
			$pie->SetPlotType('pie');
			$pie->SetDataType('text-data');
			$pie->SetTextColor('white');
			#$pie->SetGridColor('white');
			$pie->SetDataValues($data2);
			$pie->SetShading($this->shading);
			$pie->SetLabelScalePosition(0.31);
			$pie->SetDataBorderColors('black');
			$pie->SetDataColors($this->setColor($question['html_type']), 'black');

			#Dateiformat
			$pie->SetFileFormat($this->type);

			#Ausgabe in Datei
			$pie->SetIsInline(TRUE);
			$pie->SetOutputFile($this->path.$this->name.".".$this->type);
			$pie->DrawGraph();
	}

	/**
	 * Y-Achse Markierungswerte berechnen
	 *
	 * @param int $max - Maximaler Einzelwert
	 * @return int - Markierungsinterval
	 */
	 function setYTickIncrement($max){
		if($max < 11){
			return 1;
		} elseif($max < 21){
			return 2;
		} elseif($max < 51){
			return 5;
		} elseif($max < 101){
			return 10;
		} elseif($max < 201){
			return 20;
		} else{
			return 50;
		}
	}

	/**
	 * Farben definieren und an die Anzahl Antworten anpassen
	 *
	 * @param int $length - Anzahl Antworten
	 * @param int $residual - 0= ohne Rest, 1= mit Rest
	 * @param string $type - dient zur Unterscheidung, ob multiplechoice oder skala
	 * @return array mit Farbwerten
	 */
	function setColor($type)
	{
		if($type == 'checkbox' || $type == 'radio' || $type == 'select')
		{
			$colors = array('#000099', '#006600', '#ff9900', '#cc0000', '#ffcc00', '#009900', '#990000', '#330066');
		}
		else
		{
    		$colors = array('#006600', '#009900', '#ffcc00', '#ff9900', '#cc0000', '#990000', '#000099');
		}
    	return $colors;
	}
}
?>